==> fw4spl_14.0.0.orig.tar.gz: fw4spl-14.0.0/SrcLib/io/fwGdcmIO/include/fwGdcmIO/reader/iod/CTMRImageIOD.hpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2016.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWGDCMIO_READER_IOD_CTMRIMAGEIOD_HPP__
#define __FWGDCMIO_READER_IOD_CTMRIMAGEIOD_HPP__

#include "fwGdcmIO/reader/iod/InformationObjectDefinition.hpp"

namespace fwGdcmIO
{
namespace reader
{
namespace iod
{

/**
 * @brief CTMRImageIOD class used to read CT & MR Image IODs
 */
class FWGDCMIO_CLASS_API CTMRImageIOD : public ::fwGdcmIO::reader::iod::InformationObjectDefinition
{

public:

    /**
     * @brief Constructor
     * @param[in] dicomSeries DicomSeries
     * @param[in] instance Instance
     * @param[in] logger Logger
     * @param[in] progress Progress callback
     * @param[in] cancel Cancel requested callback
     */
    FWGDCMIO_API CTMRImageIOD(const ::fwMedData::DicomSeries::sptr& dicomSeries,
                              const SPTR(::fwGdcmIO::container::DicomInstance)& instance,
                              const ::fwLog::Logger::sptr& logger = nullptr,
                              ProgressCallback progress = nullptr,
                              CancelRequestedCallback cancel = nullptr);

    /// Destructor
    FWGDCMIO_API ~CTMRImageIOD();

    /**
     * @brief Read a DICOM File
     * @param[in,out] series Series that must be enriched
     */
    FWGDCMIO_API void read(::fwMedData::Series::sptr series) throw(::fwGdcmIO::exception::Failed);

    /// Enable buffer rotation
    void setBufferRotationEnabled(bool enabled)
    {
        m_enableBufferRotation = enabled;
    }

protected:
    /// Enable buffer rotation
    bool m_enableBufferRotation;
};

}  // namespace iod
}  // namespace reader
}  // namespace fwGdcmIO

#endif /*__FWGDCMIO_READER_IOD_CTMRIMAGEIOD_HPP__*/

==> fw4spl_17.2.0.orig.tar.gz: fw4spl-17.2.0/SrcLib/io/fwGdcmIO/include/fwGdcmIO/reader/iod/CTMRImageIOD.hpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2018.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#pragma once

#include "fwGdcmIO/reader/iod/InformationObjectDefinition.hpp"

namespace fwGdcmIO
{
namespace reader
{
namespace iod
{

/**
 * @brief CTMRImageIOD class used to read CT & MR Image IODs
 */
class FWGDCMIO_CLASS_API CTMRImageIOD : public ::fwGdcmIO::reader::iod::InformationObjectDefinition
{

public:

    /**
     * @brief Constructor
     * @param[in] dicomSeries DicomSeries
     * @param[in] instance Instance
     * @param[in] logger Logger
     * @param[in] progress Progress callback
     * @param[in] cancel Cancel requested callback
     */
    FWGDCMIO_API CTMRImageIOD(const ::fwMedData::DicomSeries::csptr& dicomSeries,
                              const SPTR(::fwGdcmIO::container::DicomInstance)& instance,
                              const ::fwLog::Logger::sptr& logger = nullptr,
                              ProgressCallback progress           = nullptr,
                              CancelRequestedCallback cancel      = nullptr);

    /// Destructor
    FWGDCMIO_API ~CTMRImageIOD();

    /**
     * @brief Read a DICOM File
     * @param[in,out] series Series that must be enriched
     */
    FWGDCMIO_API void read(::fwMedData::Series::sptr series) throw(::fwGdcmIO::exception::Failed);

    /// Enable buffer rotation
    void setBufferRotationEnabled(bool enabled)
    {
        m_enableBufferRotation = enabled;
    }

protected:
    /// Enable buffer rotation
    bool m_enableBufferRotation;
};

}  // namespace iod
}  // namespace reader
}  // namespace fwGdcmIO
